@@ -312,7 +312,7 @@ class AbstractBoggleBoard:
         Note: this should never be called directly by the user, but should be
         overridden in subclasses of BoggleBoard."""
 
-        raise NotImplemented, "AbstractBoggleBoard has no inherent structure."
+        return NotImplemented
 
 
     def generateBoard(self, dice, seed=-1):
